# Changelog

## Unreleased

## Version 0.12b0

Released 2020-08-14

- Change package name to opentelemetry-instrumentation-sqlalchemy
  ([#966](https://github.com/open-telemetry/opentelemetry-python/pull/966))

## 0.7b1

Released 2020-05-12

- Initial release